@@ -36,6 +36,7 @@ class Exceptions:
     EC2InstanceNotFoundException: Type[BotocoreClientError]
     EC2InstanceStateInvalidException: Type[BotocoreClientError]
     EC2InstanceTypeInvalidException: Type[BotocoreClientError]
+    EC2InstanceUnavailableException: Type[BotocoreClientError]
     InvalidArgsException: Type[BotocoreClientError]
     SerialConsoleAccessDisabledException: Type[BotocoreClientError]
     SerialConsoleSessionLimitExceededException: Type[BotocoreClientError]
@@ -69,6 +70,14 @@ class EC2InstanceConnectClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2-instance-connect.html#EC2InstanceConnect.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2_instance_connect/client/#close)
+        """
+
     def generate_presigned_url(
         self,
         ClientMethod: str,
